import React, { useState } from 'react';
import './Pay.css';

const TelepayForm = () => {
  const [error, setError] = useState(null);
  const [success, setSuccess] = useState(null);
  const [formData, setFormData] = useState({
    first_name: '',
    last_name: '',
    address: '',
    city: '',
    province: '',
    country: '',
    email: '',
    phone: '',
    description: '',
    line_items: [
      { description: '', amount: '' },
    ],
  });

  const handleChange = (field, value) => {
    setFormData({
      ...formData,
      [field]: value,
    });
  };

  const handleProductChange = (index, field, value) => {
    const updatedProducts = [...formData.line_items];
    updatedProducts[index][field] = value;

    setFormData({
      ...formData,
      line_items: updatedProducts,
    });
  };

  const handleAddProduct = () => {
    setFormData({
      ...formData,
      line_items: [...formData.line_items, { description: '', amount: '' }],
    });
  };

  const handleSubmit = async (e) => {
    e.preventDefault();

    try {
      const basicAuthHeader = 'Basic ' + btoa('test23:password');
      const response = await fetch('https://central-staging.ivrnet.com/api/v1/invoices/create', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          'Authorization': basicAuthHeader,
        },
        body: JSON.stringify(formData),
      });

      if (response.ok) {
        const responseData = await response.json();
        setSuccess(responseData);
      } else {
        const errorData = await response.json();
        setError(errorData.error || 'An error occurred');
        window.scroll({ top: 0, left: 0, behavior: 'smooth' });
      }
    } catch (error) {
      setError('An error occurred while making the API request');
      window.scroll({ top: 0, left: 0, behavior: 'smooth' });
    }
  };

  const handleDeleteLineItem = (index) => {
    const updatedLineItems = [...formData.line_items];
    updatedLineItems.splice(index, 1);
    setFormData({
      ...formData,
      line_items: updatedLineItems,
    });
  };

  return (
    <div>
      {error && (
        <div className='alert alert-danger' role='alert'>
          {error}
        </div>
      )}
      <form onSubmit={handleSubmit}>
        <div className='form-group row mb-4'>
          <div className='col'>
            <label htmlFor='firstName' className='form-label mt-1'>First Name</label>
          </div>
          <div className='col-md-9'>
            <input
              placeholder='First name'
              className='inputContainer form-control'
              value={formData.first_name}
              onChange={(e) => handleChange('firstName', e.target.value)}
            />
          </div>
        </div>
        <div className='form-group row mb-4'>
          <div className='col'>
            <label htmlFor='LastName' className='form-label mt-1'>Last Name</label>
          </div>
          <div className='col-md-9'>
            <input
              placeholder='Last name'
              className='inputContainer form-control'
              value={formData.last_name}
              onChange={(e) => handleChange('lastName', e.target.value)}
            />
          </div>
        </div>
        <div className='form-group row mb-4'>
          <div className='col'>
            <label htmlFor='Address' className='form-label mt-1'>Address</label>
          </div>
          <div className='col-md-9'>
            <input
              placeholder='Address'
              className='inputContainer form-control'
              value={formData.address}
              onChange={(e) => handleChange('address', e.target.value)}
            />
          </div>
        </div>
        <div className='form-group row mb-4'>
          <div className='col'>
            <label htmlFor='City' className='form-label mt-1'>City</label>
          </div>
          <div className='col-md-9'>
            <input
              placeholder='City'
              className='inputContainer form-control'
              value={formData.city}
              onChange={(e) => handleChange('city', e.target.value)}
            />
          </div>
        </div>
        <div className='form-group row mb-4'>
          <div className='col'>
            <label htmlFor='Province' className='form-label mt-1'>Province</label>
          </div>
          <div className='col-md-9'>
            <input
              placeholder='Province'
              className='inputContainer form-control'
              value={formData.province}
              onChange={(e) => handleChange('province', e.target.value)}
            />
          </div>
        </div>
        <div className='form-group row mb-4'>
          <div className='col'>
            <label htmlFor='Country' className='form-label mt-1'>Country</label>
          </div>
          <div className='col-md-9'>
            <input
              placeholder='Country'
              className='inputContainer form-control'
              value={formData.country}
              onChange={(e) => handleChange('country', e.target.value)}
            />
          </div>
        </div>
        <div className='form-group row mb-4'>
          <div className='col'>
            <label htmlFor='Email' className='form-label mt-1'>Email</label>
          </div>
          <div className='col-md-9'>
            <input
              placeholder='Email'
              className='inputContainer form-control'
              value={formData.email}
              type='email'
              onChange={(e) => handleChange('email', e.target.value)}
            />
          </div>
        </div>
        <div className='form-group row mb-4'>
          <div className='col'>
            <label htmlFor='Phone' className='form-label mt-1'>Phone</label>
          </div>
          <div className='col-md-9'>
            <input
              placeholder='Phone number'
              className='inputContainer form-control'
              value={formData.phone}
              onChange={(e) => handleChange('phone', e.target.value)}
            />
          </div>
        </div>
        <div className='form-group row mb-4'>
          <div className='col'>
            <label htmlFor='Description' className='form-label mt-1'>Description</label>
          </div>
          <div className='col-md-9'>
            <input
              placeholder='Enter description'
              className='inputContainer form-control'
              value={formData.description}
              onChange={(e) => handleChange('description', e.target.value)}
              required
            />
          </div>
        </div>
        <h3 className='text-center'>Line Items</h3>
        <div className='form-group row mb-4'>
          <div className='col-md-3'>
          </div>
          <div className='col-md-12'>
            {formData.line_items.map((line_items, index) => (
              <div key={index}>
                <div className='row mb-4' id={`lineItem-${index}`}>
                  <div className='col-md-5 offset-md-1'>
                    <label htmlFor={`lineItemDes-${index}`} className='form-label mt-1'>
                      Description
                    </label>
                    <input
                      placeholder='Description'
                      value={line_items.name}
                      id={`lineItemDes-${index}`}
                      className='inputContainer form-control'
                      onChange={(e) => handleProductChange(index, 'description', e.target.value)}
                      required
                    />
                  </div>
                  <div className='col-md-5'>
                    <label htmlFor={`lineItemAmount-${index}`} className='form-label mt-1'>
                      Amount
                    </label>
                    <input
                      placeholder='Enter Price'
                      type='number'
                      value={line_items.amount}
                      id={`lineItemAmount-${index}`}
                      className='inputContainer form-control'
                      onChange={(e) => handleProductChange(index, 'amount', e.target.value)}
                      required
                    />
                  </div>
                  <div className='col-md-1'>
                    <button type='button' className='btn-close' aria-label='Close'
                            onClick={() => handleDeleteLineItem(index)}></button>
                  </div>
                </div>
              </div>
            ))}
          </div>
          <div className='row'>
            <div className='col-12 pe-0'>
              <button onClick={handleAddProduct} type='button' className='btn btn-link float-end'>
                Add Line Item
              </button>
            </div>
          </div>
        </div>
        {success && (
          <div className='alert alert-primary' role='alert'>
            Access Code: {success.access_code}
          </div>
        )}
        <div className='form-group'>
          <button type='submit' className='btn btn-outline-primary'>
            Submit
          </button>
        </div>
      </form>
    </div>
  );
};

export default TelepayForm;
